@@ -60,89 +60,92 @@ def download_MapFiles(path, Resolution=10, clear=False, chunk_size=128):
     None.
 
     """
+    oldcwd = os.getcwd()
     directory = 'MappingData'
     path = os.path.join(path, directory)
 
-    if os.path.isdir(path) is False:
-        os.mkdir(path)
+    try:
+        if os.path.isdir(path) is False:
+            os.mkdir(path)
 
-    if clear == True:
-       os.chdir(path)
-       for item in os.listdir(path):
-           file_name = os.path.abspath(item)
-           os.remove(file_name)
-
-    urldict = {
-        202101: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-01m.shp.zip',
-        202103: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-03m.shp.zip',
-        202110: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-10m.shp.zip',
-        202120: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-20m.shp.zip',
-        202160: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-60m.shp.zip',
-
-        201601: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-01m.shp.zip',
-        201603: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-03m.shp.zip',
-        201610: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-10m.shp.zip',
-        201620: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-20m.shp.zip',
-        201660: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-60m.shp.zip',
-
-        201301: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-01m.shp.zip',
-        201303: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-03m.shp.zip',
-        201310: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-10m.shp.zip',
-        201320: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-20m.shp.zip',
-        201360: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-60m.shp.zip',
-
-        201001: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-01m.shp.zip',
-        201003: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-03m.shp.zip',
-        201010: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-10m.shp.zip',
-        201020: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-20m.shp.zip',
-        201060: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-60m.shp.zip',
-
-        200601: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-01m.shp.zip',
-        200603: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-03m.shp.zip',
-        200610: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-10m.shp.zip',
-        200620: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-20m.shp.zip',
-        200660: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-60m.shp.zip',
-
-        200301: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-01m.shp.zip',
-        200303: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-03m.shp.zip',
-        200310: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-10m.shp.zip',
-        200320: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-20m.shp.zip',
-    }
-
-    publist = [2021, 2016, 2013, 2010, 2006, 2003]
-    urllist = []
-    for items in publist:
-        if isinstance(Resolution, list):
-            for res in Resolution:
-                if len(str(res)) == 1:
-                    urlkey = int(str(items) + str(0) + str(res))
-                else:
-                    urlkey = int(str(items) + str(res))
-                urllist.append(urldict.get(urlkey))
-        else:
-            if len(str(Resolution)) == 1:
-                urlkey = int(str(items) + str(0) + str(Resolution))
-            else:
-                urlkey = int(str(items) + str(Resolution))
-            urllist.append(urldict.get(urlkey))
-
-    for items in urllist:
-        #print(items)
-        if items == None:
-            continue
-        r = requests.get(items, stream=True)
-        z = zipfile.ZipFile(io.BytesIO(r.content))
-        z.extractall(path)
-        extension = '.zip'
-        os.chdir(path)
-        for item in os.listdir(path):
-            if item.endswith(extension):
+        if clear == True:
+            os.chdir(path)
+            for item in os.listdir(path):
                 file_name = os.path.abspath(item)
-                zip_ref = zipfile.ZipFile(file_name)
-                zip_ref.extractall(path)
-                zip_ref.close()
                 os.remove(file_name)
 
+        urldict = {
+            202101: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-01m.shp.zip',
+            202103: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-03m.shp.zip',
+            202110: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-10m.shp.zip',
+            202120: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-20m.shp.zip',
+            202160: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2021-60m.shp.zip',
+
+            201601: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-01m.shp.zip',
+            201603: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-03m.shp.zip',
+            201610: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-10m.shp.zip',
+            201620: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-20m.shp.zip',
+            201660: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2016-60m.shp.zip',
+
+            201301: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-01m.shp.zip',
+            201303: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-03m.shp.zip',
+            201310: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-10m.shp.zip',
+            201320: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-20m.shp.zip',
+            201360: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2013-60m.shp.zip',
+
+            201001: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-01m.shp.zip',
+            201003: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-03m.shp.zip',
+            201010: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-10m.shp.zip',
+            201020: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-20m.shp.zip',
+            201060: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2010-60m.shp.zip',
+
+            200601: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-01m.shp.zip',
+            200603: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-03m.shp.zip',
+            200610: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-10m.shp.zip',
+            200620: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-20m.shp.zip',
+            200660: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2006-60m.shp.zip',
+
+            200301: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-01m.shp.zip',
+            200303: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-03m.shp.zip',
+            200310: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-10m.shp.zip',
+            200320: 'http://gisco-services.ec.europa.eu/distribution/v2/nuts/download/ref-nuts-2003-20m.shp.zip',
+        }
+
+        publist = [2021, 2016, 2013, 2010, 2006, 2003]
+        urllist = []
+        for items in publist:
+            if isinstance(Resolution, list):
+                for res in Resolution:
+                    if len(str(res)) == 1:
+                        urlkey = int(str(items) + str(0) + str(res))
+                    else:
+                        urlkey = int(str(items) + str(res))
+                    urllist.append(urldict.get(urlkey))
+            else:
+                if len(str(Resolution)) == 1:
+                    urlkey = int(str(items) + str(0) + str(Resolution))
+                else:
+                    urlkey = int(str(items) + str(Resolution))
+                urllist.append(urldict.get(urlkey))
+
+        for items in urllist:
+            if items == None:
+                continue
+            r = requests.get(items, stream=True)
+            z = zipfile.ZipFile(io.BytesIO(r.content))
+            z.extractall(path)
+            extension = '.zip'
+            os.chdir(path)
+            for item in os.listdir(path):
+                if item.endswith(extension):
+                    file_name = os.path.abspath(item)
+                    zip_ref = zipfile.ZipFile(file_name)
+                    zip_ref.extractall(path)
+                    zip_ref.close()
+                    os.remove(file_name)
+    finally:
+        os.chdir(oldcwd)
+
 
 def download_NACE_TransitionTables(path):
     """
@@ -235,9 +238,25 @@ def merge_frompickle(path, force_rerun=False):
     return None
 
 
+def get_rootpath():
+    """
+    Returns the current rootpath, stored in the config file.
+
+    Returns
+    -------
+    path : String
+        Current path to the root of the project, stored in the config file.
+
+    """
+    config = configparser.ConfigParser()
+    config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'))
+    path = config['PATH']['path']
+    return path
+
+
 def change_rootpath(path):
     """
-    changes the Path of the root to the project in the configuration.ini file
+    Changes the path of the root to the project in the configuration.ini file.
 
     Parameters
     ----------
@@ -258,7 +277,7 @@ def change_rootpath(path):
 
 def init_emipy_project(path, Resolution=10, force_rerun=False):
     """
-    Executes the initiation of a new project. Downloads all needed data and to the given path and merges data of interest.
+    Executes the initiation of a new project. Downloads all needed data to the given path and merges data of interest.
 
     Parameters
     ----------
